# Please keep this package in sync with FC

# "fix" underlinking:
%define _disable_ld_no_undefined 1

%global major 1
%define libname %mklibname virglrenderer %major
%define devname %mklibname -d virglrenderer

# Define the gitdate below and download the tarball using 
# make-git-snapshot.sh <commit> to retrieve the snapshot version.
#
#global gitdate 20241201
#global gitversion 41f2587c

# To be sure that mass_rebuild script can increase the rel
%define rel 1

# for vulkan (see https://docs.mesa3d.org/drivers/venus.html)
%define enable_venus	1

Name:		virglrenderer
Version:	1.1.0
Release:	%mkrel %{?gitdate:%{rel}.%{gitdate}git%{gitversion}}%{!?gitdate:%rel}

Summary:	The VirGL virtual OpenGL renderer
Group:		Emulators
License:	MIT

%if 0%{?gitdate}
Source0:	virglrenderer-%{gitdate}.tar.xz
%else
Source0:	https://gitlab.freedesktop.org/virgl/virglrenderer/-/archive/%{version}/virglrenderer-%{version}.tar.bz2
%endif
Source1:	make-git-snapshot.sh

BuildRequires:  meson
BuildRequires:	x11-util-macros
BuildRequires:	pkgconfig(epoxy)
BuildRequires:	pkgconfig(gbm)
BuildRequires:	pkgconfig(egl)
BuildRequires:	python3
BuildRequires:	pkgconfig(libdrm)
BuildRequires:	pkgconfig(libva)
%if 0%{?enable_venus}
BuildRequires:	pkgconfig(vulkan)
%endif

%description
The Virgil3D rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

%package -n %libname
Summary: Virgl Rendering library
Group:	Emulators

%description -n %libname
The Virgil3D rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

%package -n %devname
Summary: Virgil3D renderer development files
Group:	Emulators
Provides: %{name}-devel
Requires: %{libname} = %{version}-%{release}

%description -n %devname
Virgil3D renderer development files, used by
qemu to build against.

%package test-server
Summary: Virgil3D renderer testing server
Group:	Emulators
Requires: %{libname} = %{version}-%{release}
%if 0%{?enable_venus}
Requires: %{name}-vulkan = %{version}-%{release}
%endif

%description test-server
Virgil3D renderer testing server is a server
that can be used along with the mesa virgl
driver to test virgl rendering without GL.

%package vulkan
Summary: Virgil3D renderer vulkan files
Group: Emulators

%description vulkan
The Virgil3D rendering library is a library used by
qemu to implement 3D GPU support for the virtio GPU.

This package contains the extra files for the Venus
Virtio-GPU protocol for Vulkan command serialization.


%prep
%if 0%{?gitdate}
%setup -q -n %{name}-%{gitdate}
%else
%setup -q -n %{name}-%{version}
%endif
%autopatch -p1

%build
%meson \
%if 0%{?enable_venus}
-Dvenus=true \
-Dvenus-validate=true \
%endif
-Dvideo=true
%meson_build

%install
%meson_install
find %{buildroot} -type f -name '*.la' | xargs rm -f -- || :



%files -n %libname
%license COPYING
%{_libdir}/lib*.so.*

%files -n %devname
%dir %{_includedir}/virgl/
%{_includedir}/virgl/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files test-server
%{_bindir}/virgl_test_server

%files vulkan
%if 0%{?enable_venus}
%{_libexecdir}/virgl_render_server
%endif


%changelog
* Sun Dec 01 2024 ghibo <ghibo> 1.1.0-1.mga10
+ Revision: 2120383
- Update to version 1.1.0.
- Sync with FC.
- Enable venus for vulkan.

* Thu Jan 05 2023 tv <tv> 0.10.4-1.20230104git88b9fe3b.mga9
+ Revision: 1930164
- Upstream release 0.10.4

* Tue Nov 08 2022 tv <tv> 0.10.1-2.20220912git19dc97a2.mga9
+ Revision: 1904694
- Upstream release 0.10.1

* Thu Oct 20 2022 ns80 <ns80> 0.9.1-2.20210420git36391559.mga9
+ Revision: 1897871
- add upstream patches for CVE-2022-0135 and CVE-2022-0175 (mga#29903)

* Thu May 06 2021 tv <tv> 0.9.1-1.20210420git36391559.mga9
+ Revision: 1721663
- Upstream release 0.9.1

* Wed Feb 12 2020 tv <tv> 1.20200212git7d204f39.mga8-current
+ Revision: 1509347
- Upstream release 0.8.2

* Sat Dec 21 2019 tv <tv> 0.8.1-1.20191220git66c57963.mga8
+ Revision: 1469227
- Upstream release 0.8.1

* Fri Oct 04 2019 tv <tv> 0.8.0-1.20191002git4ac3a04c.mga8
+ Revision: 1449242
- new snapshot
- 0.8.0

* Wed Apr 24 2019 tv <tv> 0.7.0-1.20190424gitd1758cc09.mga7
+ Revision: 1395132
- Latest upstream git snapshot
- enable debug package

* Thu Sep 20 2018 tv <tv> 0.7.0-1.mga7
+ Revision: 1279595
- upstream 0.7.0 release

* Mon Jul 17 2017 tv <tv> 0.6.0-1.mga7
+ Revision: 1124072
- new release

* Fri Apr 15 2016 tv <tv> 0.5.0-1.mga6
+ Revision: 1001612
- imported package virglrenderer


* Fri Apr 15 2016 Thierry Vignaud <tv@mageia.org> 0.5.0-1.mga6
- import from FC

* Mon Apr 11 2016 Dave Airlie <airlied@redhat.com> 0.5.0-1.git
- upstream 0.5.0 release

* Thu Feb 18 2016 Dave Airlie <airlied@redhat.com> 0.4.1-1.git
- fix regression in last build

* Wed Feb 17 2016 Dave Airlie <airlied@redhat.com> 0.4.0-1.git
- latest git snapshot with new API

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-3.20151215gite9d3c0c27
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Dec 15 2015 Dave Airlie <airlied@redhat.com> 0.3.0-2.gite9d3c0c27
- latest upstream to fix gnome-shell rendering bugs

* Fri Oct 23 2015 Dave Airlie <airlied@redhat.com> 0.3.0-1.20151023git9ce005e5a
- update to latest upstream to fix shader issue

* Fri Oct 23 2015 Dave Airlie <airlied@redhat.com> 0.2.0-1.20151023git5bfba5190
- update to latest upstream

* Thu Jul 09 2015 Dave Airlie <airlied@redhat.com> 0.0.1-0.20150420gitc4fb40201.2
- fix FTBFS (#1240041)

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.1-0.20150420gitc4fb40201.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Apr 01 2015 Dave Airlie <airlied@redhat.com> 0.0.1-0.20150401gita9ba2c442
- initial virglrenderer spec


